# fitz_ai/cli/commands/__init__.py
"""CLI commands."""

from fitz_ai.cli.commands import (
    chat,
    collections,
    config,
    doctor,
    ingest,
    init,
    query,
    quickstart,
)

__all__ = [
    "chat",
    "collections",
    "config",
    "doctor",
    "ingest",
    "init",
    "query",
    "quickstart",
]
